Visualization Functions
=======================

Advanced visualization functions for comprehensive data exploration and analysis.

.. currentmodule:: edaflow

Distribution Analysis
---------------------

.. autofunction:: visualize_numerical_boxplots

.. autofunction:: visualize_interactive_boxplots

.. autofunction:: visualize_histograms

Relationship Analysis
---------------------

.. autofunction:: visualize_heatmap

.. autofunction:: visualize_scatter_matrix

Categorical Analysis
--------------------

.. autofunction:: visualize_categorical_values
